dnl======================================================================
dnl AC_GDS_FINISH - Things to be done at the very end for GDS
dnl======================================================================
 
AC_DEFUN([AC_GDS_FINISH],
[
  dnl ===================================================================
  dnl  Setup $architecture
  dnl ===================================================================
architecture=
case "${host}" in
*linux*) architecture="linux" ;;
*solaris*) architecture="solaris" ;;
*darwin*) architecture="darwin" ;;
esac
AC_SUBST(architecture)
  dnl ===================================================================
  dnl  Setup $syslibs
  dnl ===================================================================
syslibs=
case "${host}" in
*linux*) syslibs="-lm -ldl -lrt" ;;
*solaris*) syslibs="-lm -ldl -lrt" ;;
*darwin*) syslibs="-lm -ldl" ;;
esac
AC_SUBST(syslibs)
  dnl ===================================================================
  dnl  Setup $sysmtlibs
  dnl ===================================================================
sysmtlibs=
case "${host}" in
*linux*) sysmtlibs="-lm -ldl -lrt -lpthread" ;;
*solaris*) sysmtlibs="-lm -ldl -lrt -lpthread" ;;
*darwin*) sysmtlibs="-lm -ldl -lpthread" ;;
esac
AC_SUBST(sysmtlibs)
  dnl ===================================================================
  dnl  Setup $netlib
  dnl ===================================================================
netlib=
case "${host}" in
*linux*) netlib="" ;;
*solaris*) netlib="-lnsl -lsocket" ;;
*darwin*) netlib="" ;;
esac
AC_SUBST(netlib)
  dnl ===================================================================
  dnl  Setup $readlinelibs
  dnl ===================================================================
readlinelibs=
case "${host}" in
*linux*) readlinelibs="-lreadline -ltermcap" ;;
*solaris*) readlinelibs="-lreadline -ltermcap" ;;
*darwin*) readlinelibs="-lreadline -ltermcap" ;;
esac
AC_SUBST(readlinelibs)
  dnl ===================================================================
  dnl  Specify warning message level
  dnl ===================================================================
case "$GDS_CC_FLAVOR" in
gnu)
  CFLAGS="$CFLAGS -pipe -fPIC $unix98flags"
  WARNINGCFLAGS="-Wall"
  ;;
clang)
  CFLAGS="$CFLAGS -pipe -fPIC $unix98flags"
  WARNINGCFLAGS="-Wall"
  ;;
intel)
  CFLAGS="$CFLAGS -pipe -fPIC $unix98flags"
  WARNINGCFLAGS="-Wall"
  ;;
SunPRO)
  CFLAGS="$CFLAGS -v -KPIC -xc99=none"
  ;;
esac
case "$GDS_CXX_FLAVOR" in
gnu)
  CXXFLAGS="$CXXFLAGS -pipe -fPIC"
  WARNINGCXXFLAGS="-Wall -Woverloaded-virtual -Wno-deprecated"
  ;;
clang)
  CXXFLAGS="$CXXFLAGS -pipe -fPIC"
  WARNINGCXXFLAGS="-Wall -Woverloaded-virtual -Wno-deprecated -Wno-unused-const-variable"
  LDFLAGS="$LDFLAGS -Wc,-Qunused-arguments"
  ;;
intel)
  CXXFLAGS="$CXXFLAGS -pipe -fPIC"
  WARNINGCXXFLAGS="-Wall -Woverloaded-virtual -Wno-deprecated"
  ;;
SunPRO)
  CXXFLAGS="$CXXFLAGS -KPIC"
  ;;
esac
  dnl ===================================================================
  dnl  Specify optimization
  dnl ===================================================================
opt="-O2"
hiopt="-O3"
noopt="-O0"
  dnl ===================================================================
  dnl   Add POSIX source flag to optimization
  dnl ===================================================================
case "$GDS_CC_FLAVOR" in
gnu|clang)
  opt95="$opt $posix95flags"
  hiopt95="$hiopt $posix95flags"
  noopt95="$noopt $posix95flags"
  opt="$opt $posixflags"
  hiopt="$hiopt $posixflags"
  noopt="$noopt $posixflags"
  ;;
SunPRO)
  opt95="$opt"
  hiopt95="$hiopt"
  noopt95="$noopt"
  ;;
esac
AC_SUBST(opt)
AC_SUBST(hiopt)
AC_SUBST(noopt)
AC_SUBST(opt95)
AC_SUBST(hiopt95)
AC_SUBST(noopt95)
  dnl ===================================================================
  dnl  Instruct how to handle Version Control Id Tag
  dnl ===================================================================
  case "$GDS_CC_FLAVOR" in
  gnu)
    CFLAGS="$CFLAGS '-DVCSID(x)=static const char* __attribute__((__unused__)) versionId = x'"
    ;;
  clang)
    CFLAGS="$CFLAGS '-DVCSID(x)=static const char* __attribute__((__unused__)) versionId = x'"
    ;;
  *)
    CFLAGS="$CFLAGS '-DVCSID(x)=static const char* versionId = x;'"
    ;;
  esac
  case "$GDS_CXX_FLAVOR" in
  *)
    CXXFLAGS="$CXXFLAGS '-DVCSID(x)=static const char* versionId[[]] = { versionId[[1]], x }'"
    ;;
  esac
])
